#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 refinery
version:              0.4.0.0
visibility:           public
id:                   refinery-0.4.0.0-3UXqTSk9OacBHGDQ6Mnene
key:                  refinery-0.4.0.0-3UXqTSk9OacBHGDQ6Mnene
license:              BSD-3-Clause
copyright:            2019 Reed Mullanix
maintainer:           reedmullanix@gmail.com
author:               Reed Mullanix
homepage:             https://github.com/totbwf/refinery#readme
synopsis:             Toolkit for building proof automation systems
description:
    Please see the README on GitHub at <https://github.com/githubuser/refinery#readme>

category:             Language
abi:                  f0276960f6ffb4cc552e61f0792d408f
exposed:              True
exposed-modules:
    Refinery.ProofState Refinery.Tactic Refinery.Tactic.Internal

hidden-modules:       Paths_refinery
import-dirs:          /usr/lib/ghc-9.6.6/site-local/refinery-0.4.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/refinery-0.4.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/refinery-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-refinery
hs-libraries:         HSrefinery-0.4.0.0-3UXqTSk9OacBHGDQ6Mnene
depends:
    base-4.18.2.1 exceptions-0.10.7 mmorph-1.2.2-I879kMQXeoiA7V1mSxl9UH
    mtl-2.3.1

haddock-interfaces:   /usr/share/doc/haskell-refinery/html/refinery.haddock
haddock-html:         /usr/share/doc/haskell-refinery/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

